==> gnustep-gui_0.9.5.orig.tar.gz: gnustep-gui-0.9.5.orig/TextConverters/RTF/RTFConsumer.h <==
/* rtfConsumer.h created by pingu on Fri 12-Nov-1999

   Copyright (C) 1999 Free Software Foundation, Inc.

   Author:  Stefan Bhringer (stefan.boehringer@uni-bochum.de)
   Date: Dec 1999

   This file is part of the GNUstep GUI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _rtfConsumer_h_INCLUDE
#define _rtfConsumer_h_INCLUDE

#include <GNUstepGUI/GSTextConverter.h>

@class NSMutableDictionary;
@class NSMutableArray;
@class NSMutableAttributedString;

@interface RTFConsumer: NSObject <GSTextConsumer>
{
@public
  NSMutableDictionary *documentAttributes;
  NSMutableDictionary *fonts;
  NSMutableArray *colours;
  NSMutableArray *attrs;
  NSMutableAttributedString *result;
  Class _class;
  int ignore;
}

@end

@interface RTFDConsumer: RTFConsumer
@end

#endif

==> gnustep-gui_0.10.2.orig.tar.gz: gnustep-gui-0.10.2/TextConverters/RTF/RTFConsumer.h <==
/* rtfConsumer.h created by pingu on Fri 12-Nov-1999

   Copyright (C) 1999 Free Software Foundation, Inc.

   Author:  Stefan Bhringer (stefan.boehringer@uni-bochum.de)
   Date: Dec 1999

   This file is part of the GNUstep GUI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; see the file COPYING.LIB.
   If not, write to the Free Software Foundation,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef _rtfConsumer_h_INCLUDE
#define _rtfConsumer_h_INCLUDE

#include <GNUstepGUI/GSTextConverter.h>

@class NSMutableDictionary;
@class NSMutableArray;
@class NSMutableAttributedString;

@interface RTFConsumer: NSObject <GSTextConsumer>
{
@public
  NSMutableDictionary *documentAttributes;
  NSMutableDictionary *fonts;
  NSMutableArray *colours;
  NSMutableArray *attrs;
  NSMutableAttributedString *result;
  Class _class;
  int ignore;
}

@end

@interface RTFDConsumer: RTFConsumer
@end

#endif
